@@ -17,7 +17,7 @@ vserver!1170!rule!10!handler!rewrite!1!substring = %s$1
 
 class Test (TestBase):
     def __init__ (self):
-        TestBase.__init__ (self)
+        TestBase.__init__ (self, __file__)
         self.name = "Domain to subdir"
 
         self.request           = "GET /%s HTTP/1.1\r\n" %(PATH) + \
